@@ -271,7 +271,7 @@ class Zone:
 
     def get_host(self, host):
         """Return the (rtype, [values, ]) if the host exists in this domain on AWS, None otherwise."""
-        for rrecord in self.conn.get_all_rrsets(self.id, name=host):
+        for rrecord in self.conn.get_all_rrsets(self.id): #Adding name=host is not working in boto.
             log.debug(rrecord.name)
             if host == rrecord.name.split('.', 1)[0]:
                 return (rrecord.type, rrecord.resource_records)
